<?php
/**
 * Single Product Image
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-image.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.3.2
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $post, $product;

$columns           = apply_filters( 'woocommerce_product_thumbnails_columns', 4 );
$thumbnail_size    = apply_filters( 'woocommerce_product_thumbnails_large_size', 'full' );
$post_thumbnail_id = $product->get_image_id();
$full_size_image   = wp_get_attachment_image_src( $post_thumbnail_id, $thumbnail_size );
$placeholder       = has_post_thumbnail() ? 'with-images' : 'without-images';
$wrapper_classes   = apply_filters( 'woocommerce_single_product_image_gallery_classes', array(
	'woocommerce-product-gallery',
	'woocommerce-product-gallery--' . $placeholder,
	'woocommerce-product-gallery--columns-' . absint( $columns ),
	'images',
) );
?>


<div class="<?php echo esc_attr( implode( ' ', array_map( 'sanitize_html_class', $wrapper_classes ) ) ); ?>" data-columns="<?php echo esc_attr( $columns ); ?>" >
<figure class="woocommerce-product-gallery__wrapper">
	
<div id="product-slider"  class="postImage images">
	<ul class="slides">
		<li data-thumb="<?php echo get_the_post_thumbnail_url( $post->ID, 'shop_thumbnail' ) ?>" class="woocommerce-product-gallery__image">
		
		<?php
		if ( has_post_thumbnail() ) {

			$image_title 		= esc_attr( get_the_title( get_post_thumbnail_id() ) );
			$image_link  		= wp_get_attachment_url( get_post_thumbnail_id() );
			$props            = wc_get_product_attachment_props( get_post_thumbnail_id(), $post );
			$image       		= get_the_post_thumbnail( $post->ID, apply_filters( 'single_product_large_thumbnail_size', 'shop_single' ), array(
				'title'	 => $props['title'],
				'alt'    => $props['alt'],
				) );
			$attachment_count   = count( $product->get_gallery_image_ids() );

			if ( $attachment_count > 0 ) {
				$gallery = '[product-gallery]';
			} else {
				$gallery = '';
			}
		
		$class_zoom = '';
		if(get_option('sense_thumb_zoom') != 'hide') {
			$class_zoom = 'cloud-zoom';
		}
		
		$attributes = array(
			'title'                   => get_post_field( 'post_title', $post_thumbnail_id ),
			'data-caption'            => get_post_field( 'post_excerpt', $post_thumbnail_id ),
			'class' => $class_zoom,
			'srcset' => ' ',
		);
		
		?>
		
		<?php echo get_the_post_thumbnail( $post->ID, 'full', $attributes ); ?>
		
		<a rel="product-images" data-rel="prettyPhoto<?php echo $gallery; ?>" class="fancybox fullscreen-button woocommerce-main-image" href="<?php echo $image_link; ?>" >
			
			<div class="product-fullscreen">
				<i class="icons icon-resize-full-1"></i>
			</div>
			
		</a>
		
		<?php	
		} else {
		?>
		<img class="<?php echo $class_zoom; ?>" src="<?php echo woocommerce_placeholder_img_src(); ?>" data-large="<?php echo woocommerce_placeholder_img_src(); ?>" alt="Placeholder" />
		<a class="fullscreen-button" href="<?php echo woocommerce_placeholder_img_src(); ?>">
			<div class="product-fullscreen">
				<i class="icons icon-resize-full-1"></i>
			</div>
		</a>
		
		<?php	
		}
	    ?>
			
		</li>
		
	</ul>
	
</div>

</figure>

<?php do_action( 'woocommerce_product_thumbnails' ); ?>
</div>



